@@ -1,18 +1,17 @@
 # (C) 2021 GoodData Corporation
 from pathlib import Path
 
-import vcr
+from tests_support.vcrpy_utils import get_vcr
 
 from gooddata_fdw import GoodDataForeignDataWrapper as fdw
-from tests import VCR_MATCH_ON
+
+gd_vcr = get_vcr()
 
 _current_dir = Path(__file__).parent.absolute()
 _fixtures_dir = _current_dir / "fixtures"
 
-gd_vcr = vcr.VCR(filter_headers=["authorization", "user-agent"], serializer="json", match_on=VCR_MATCH_ON)
 
-
-@gd_vcr.use_cassette(str(_fixtures_dir / "import_compute_without_restrictions.json"))
+@gd_vcr.use_cassette(str(_fixtures_dir / "import_compute_without_restrictions.yaml"))
 def test_import_compute_without_restrictions(test_config):
     tables = fdw.import_schema(
         schema=test_config["workspace"],
@@ -31,7 +30,7 @@ def test_import_compute_without_restrictions(test_config):
     assert "order_amount" in compute_table.col_idx
     assert "percent_revenue" in compute_table.col_idx
     # fact
-    assert "campaign_channels_budget" in compute_table.col_idx
+    assert "budget" in compute_table.col_idx
     # date attribute label
     assert "date_day" in compute_table.col_idx
     # normal label
@@ -43,8 +42,8 @@ def test_import_compute_without_restrictions(test_config):
     assert compute_table.col_idx["percent_revenue"].type_name == "DECIMAL(24, 1)"
     assert compute_table.col_idx["percent_revenue"].options["id"] == "metric/percent_revenue"
 
-    assert compute_table.col_idx["campaign_channels_budget"].type_name == "DECIMAL(24, 2)"
-    assert compute_table.col_idx["campaign_channels_budget"].options["id"] == "fact/campaign_channels.budget"
+    assert compute_table.col_idx["budget"].type_name == "DECIMAL(24, 2)"
+    assert compute_table.col_idx["budget"].options["id"] == "fact/budget"
 
     assert compute_table.col_idx["date_day"].type_name == "DATE"
     assert compute_table.col_idx["date_day"].options["id"] == "label/date.day"
